@@ -2,7 +2,7 @@
 #ifndef _GLIBMM_CONTAINERS_H
 #define _GLIBMM_CONTAINERS_H
 
-/* $Id: containers.h,v 1.3 2004/03/13 22:11:51 murrayc Exp $ */
+/* $Id: containers.h,v 1.3.2.1 2005/01/21 20:12:50 murrayc Exp $ */
 
 /* containers.h
  *
@@ -228,7 +228,14 @@ public:
       //because that would be "dependent", and g++ 3.4 does not allow that.
       //The specific Glib::wrap() overloads don't do anything special anyway.
       GObject* cobj = static_cast<GObject*>( (*node_).data );
+      
+      #ifdef GLIBMM_CAN_USE_DYNAMIC_CAST_IN_UNUSED_TEMPLATE_WITHOUT_DEFINITION
       return *(dynamic_cast<pointer>(Glib::wrap_auto(cobj, false /* take_copy */)));
+      #else
+      //We really do need to use dynamic_cast<>, so I expect problems if this code is used. murrayc.
+      return *(static_cast<pointer>(Glib::wrap_auto(cobj, false /* take_copy */)));
+      #endif
+      
     }
     
     return *(pointer)glibmm_null_pointer;
