@@ -1,5 +1,5 @@
 // -*- c++ -*-
-/* $Id: main.cc,v 1.3 2004/02/10 14:26:04 murrayc Exp $ */
+/* $Id: main.cc,v 1.7 2004/08/01 16:16:44 mschulze Exp $ */
 
 /* Copyright (C) 2002 The gtkmm Development Team
  *
@@ -62,14 +62,16 @@ void* SourceConnectionNode::notify(void* data)
 {
   SourceConnectionNode *const self = static_cast<SourceConnectionNode*>(data);
 
-  // if there is no object, this call was triggered from destroy_notify_handler().
+  // if there is no object, this call was triggered from destroy_notify_handler(),
+  // because we set self->source_ to 0 there:
   if (self->source_)
   {
     GSource* s = self->source_;  
     self->source_ = 0;
-    g_source_destroy(self->source_);
+    g_source_destroy(s);
 
-    delete self;
+    // Destroying the object triggers execution of destroy_notify_handler(),
+    // eiter immediately or later, so we leave that to do the deletion.
   }
 
   return 0;
@@ -80,8 +82,7 @@ void SourceConnectionNode::destroy_notify_callback(void* data)
 {
   SourceConnectionNode *const self = static_cast<SourceConnectionNode*>(data);
 
-  // if there is no object, this call was triggered from notify().
-  if (self->source_)
+  if (self)
   {
     // The GLib side is disconnected now, thus the GSource* is no longer valid.
     self->source_ = 0;
@@ -553,6 +554,12 @@ Glib::RefPtr<MainContext> MainLoop::get_context()
   return Glib::wrap(g_main_loop_get_context(gobj()), true);
 }
 
+//static:
+int MainLoop::depth()
+{
+  return g_main_depth();
+}                                             
+
 void MainLoop::reference() const
 {
   g_main_loop_ref(reinterpret_cast<GMainLoop*>(const_cast<MainLoop*>(this)));
